@@ -45,44 +45,17 @@ from pandas.tseries.api import *
 from pandas.core.computation.api import *
 from pandas.core.reshape.api import *
 
-# deprecate tools.plotting, plot_params and scatter_matrix on the top namespace
-import pandas.tools.plotting
-plot_params = pandas.plotting._style._Options(deprecated=True)
-# do not import deprecate to top namespace
-scatter_matrix = pandas.util._decorators.deprecate(
-    'pandas.scatter_matrix', pandas.plotting.scatter_matrix, '0.20.0',
-    'pandas.plotting.scatter_matrix')
-
 from pandas.util._print_versions import show_versions
 from pandas.io.api import *
 from pandas.util._tester import test
 import pandas.testing
-
-# extension module deprecations
-from pandas.util._depr_module import _DeprecatedModule
-
-json = _DeprecatedModule(deprmod='pandas.json',
-                         moved={'dumps': 'pandas.io.json.dumps',
-                                'loads': 'pandas.io.json.loads'})
-parser = _DeprecatedModule(deprmod='pandas.parser',
-                           removals=['na_values'],
-                           moved={'CParserError': 'pandas.errors.ParserError'})
-lib = _DeprecatedModule(deprmod='pandas.lib', deprmodto=False,
-                        moved={'Timestamp': 'pandas.Timestamp',
-                               'Timedelta': 'pandas.Timedelta',
-                               'NaT': 'pandas.NaT',
-                               'infer_dtype': 'pandas.api.types.infer_dtype'})
-tslib = _DeprecatedModule(deprmod='pandas.tslib',
-                          moved={'Timestamp': 'pandas.Timestamp',
-                                 'Timedelta': 'pandas.Timedelta',
-                                 'NaT': 'pandas.NaT',
-                                 'NaTType': 'type(pandas.NaT)',
-                                 'OutOfBoundsDatetime': 'pandas.errors.OutOfBoundsDatetime'})
+import pandas.arrays
 
 # use the closest tagged version if possible
 from ._version import get_versions
 v = get_versions()
 __version__ = v.get('closest-tag', v['version'])
+__git_version__ = v.get('full-revisionid')
 del get_versions, v
 
 # module level doc-string
